@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 
-""""
+"""
 This module provides a QueryEngine that simplifies queries for Mongo databases
 generated using hive.
 """
@@ -115,7 +115,6 @@ class QueryEngine(object):
             self.aliases = aliases_config["aliases"]
             self.defaults = aliases_config["defaults"]
 
-
     def __enter__(self):
         """Allows for use with the 'with' context manager"""
         return self
@@ -428,11 +427,11 @@ class QueryResults(Iterable):
                 data = r[v[0]]
                 for j in range(1, len(v)):
                     if isinstance(data, list):
-                        data = data[int(v[j])]
+                        data = [d[v[j]] for d in data]
                     else:
                         data = data[v[j]]
                 result[k] = data
-            except:
+            except (IndexError, KeyError, ValueError):
                 result[k] = None
         return result
 
