@@ -1,11 +1,11 @@
 # Create your views here.
 
 import json
+import re
 
 from django.template import RequestContext
 from django.shortcuts import render_to_response
-from django.http import HttpResponse, HttpResponseBadRequest, \
-    HttpResponseForbidden
+from django.http import HttpResponse
 from django.views.decorators.csrf import csrf_exempt
 import os
 from matgendb.query_engine import QueryEngine
@@ -30,36 +30,37 @@ def index(request):
     return render_to_response("home/templates/index.html",
                               RequestContext(request, d))
 
+
 @csrf_exempt
 def query(request):
     if request.method == 'POST':
         try:
-            critstr = request.POST["criteria"]
-            try:
-                criteria = {"pretty_formula": Composition(critstr).reduced_formula}
-            except:
-                try:
-                    criteria = {"task_id": int(critstr)}
-                except ValueError:
-                    try:
-                        syms = [Element(sym).symbol
-                                for sym in critstr.split("-")]
-                        syms.sort()
-                        criteria = {"chemsys": "-".join(syms)}
-                    except:
-                        criteria = json.loads(critstr)
+            critstr = request.POST["criteria"].strip()
+            if re.match("^[\w\(\)]+$", critstr):
+                comp = Composition(critstr)
+                criteria = {"pretty_formula": comp.reduced_formula}
+            elif re.match("^\d+$", critstr):
+                criteria = {"task_id": int(critstr)}
+            elif re.match("^[A-Za-z\-]+$", critstr):
+                syms = [Element(sym).symbol
+                        for sym in critstr.split("-")]
+                syms.sort()
+                criteria = {"chemsys": "-".join(syms)}
+            else:
+                criteria = json.loads(critstr)
             properties = request.POST["properties"].split()
             if not properties:
                 properties = None
-        except ValueError:
+        except ValueError as ex:
             d = {"valid_response": False,
-                 "error_msg": "Bad criteria or properties."}
+                 "error_msg": "Bad criteria / properties: {}".format(str(ex))}
             return HttpResponse(
                 json.dumps(d), mimetype="application/json")
 
-
         results = list(qe.query(criteria=criteria,
                                 properties=properties))
+        if properties is None and len(results) > 0:
+            properties = list(results[0].keys())
         d = {"valid_response": True, "results": results,
              "properties": properties}
         return HttpResponse(json.dumps(d, cls=MongoJSONEncoder),
@@ -70,11 +71,6 @@ class MongoJSONEncoder(DjangoJSONEncoder):
     """
     Encodes Mongo DB objects into JSON
     In particular is handles BSON Object IDs and Datetime objects
-
-    eg.
-
-    >>> from django.core.serializers import json
-    >>> json.dumps(mongo_doc, cls=MongoJSONEncoder)
     """
 
     def default(self, obj):
